@@ -4,7 +4,6 @@ import (
 	"errors"
 	"log/slog"
 	"os"
-	"os/exec"
 	"path/filepath"
 	"reflect"
 	"slices"
@@ -14,35 +13,34 @@ import (
 	"github.com/yorukot/superfile/src/config/icon"
 	"github.com/yorukot/superfile/src/internal/common"
 	"github.com/yorukot/superfile/src/internal/ui/metadata"
+	"github.com/yorukot/superfile/src/internal/ui/notify"
 	"github.com/yorukot/superfile/src/internal/utils"
 
 	"github.com/barasher/go-exiftool"
 	"github.com/charmbracelet/bubbles/textinput"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/lipgloss"
+	"github.com/charmbracelet/x/ansi"
+
 	variable "github.com/yorukot/superfile/src/config"
+	zoxideui "github.com/yorukot/superfile/src/internal/ui/zoxide"
 	stringfunction "github.com/yorukot/superfile/src/pkg/string_function"
 )
 
 // These represent model's state information, its not a global preperty
-var LastTimeCursorMove = [2]int{int(time.Now().UnixMicro()), 0} //nolint: gochecknoglobals // TODO : Move to model struct
-var ListeningMessage = true                                     //nolint: gochecknoglobals // TODO : Move to model struct
-var hasTrash = true                                             //nolint: gochecknoglobals // TODO : Move to model struct
-var batCmd = ""                                                 //nolint: gochecknoglobals // TODO : Move to model struct
-var et *exiftool.Exiftool                                       //nolint: gochecknoglobals // TODO : Move to model struct
-var channel = make(chan channelMessage, 1000)                   //nolint: gochecknoglobals // TODO : Move to model struct
-var progressBarLastRenderTime = time.Now()                      //nolint: gochecknoglobals // TODO : Move to model struct
+var (
+	LastTimeCursorMove = [2]int{int(time.Now().UnixMicro()), 0} //nolint: gochecknoglobals // TODO: Move to model struct
+	et                 *exiftool.Exiftool                       //nolint: gochecknoglobals // TODO: Move to model struct
+)
 
 // Initialize and return model with default configs
 // It returns only tea.Model because when it used in main, the return value
 // is passed to tea.NewProgram() which accepts tea.Model
 // Either way type 'model' is not exported, so there is not way main package can
 // be aware of it, and use it directly
-func InitialModel(firstFilePanelDirs []string, firstUseCheck, hasTrashCheck bool) tea.Model {
-	toggleDotFile, toggleFooter := initialConfig(firstFilePanelDirs)
-	hasTrash = hasTrashCheck
-	batCmd = checkBatCmd()
-	return defaultModelConfig(toggleDotFile, toggleFooter, firstUseCheck, firstFilePanelDirs)
+func InitialModel(firstFilePanelDirs []string, firstUseCheck bool) tea.Model {
+	toggleDotFile, toggleFooter, zClient := initialConfig(firstFilePanelDirs)
+	return defaultModelConfig(toggleDotFile, toggleFooter, firstUseCheck, firstFilePanelDirs, zClient)
 }
 
 // Init function to be called by Bubble tea framework, sets windows title,
@@ -50,92 +48,131 @@ func InitialModel(firstFilePanelDirs []string, firstUseCheck, hasTrashCheck bool
 // Note : What init should do, for example read file panel data, read sidebar directories, and
 // disk, is being done in at the creation of model of object. Right now creation of model object
 // and its initialization isn't well separated.
-func (m model) Init() tea.Cmd {
+func (m *model) Init() tea.Cmd {
 	return tea.Batch(
 		tea.SetWindowTitle("superfile"),
 		textinput.Blink, // Assuming textinput.Blink is a valid command
-		listenForChannelMessage(channel),
+		processCmdToTeaCmd(m.processBarModel.GetListenCmd()),
 	)
 }
 
 // Update function for bubble tea to provide internal communication to the
 // application
-func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
+func (m *model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 	// TODO : We could check for m.modelQuitState and skip doing anything
 	// If its quitDone. But if we are at this state, its already bad, so we need
 	// to first figure out if its possible in testing, and fix it.
-	slog.Debug("model.Update() called")
-	var cmd tea.Cmd
+	slog.Debug("model.Update() called", "msgType", reflect.TypeOf(msg))
+	var sidebarCmd, inputCmd, updateCmd, panelCmd, metadataCmd, filePreviewCmd tea.Cmd
+	gotModelUpdateMsg := false
 
-	cmd = m.sidebarModel.UpdateState(msg)
+	sidebarCmd = m.sidebarModel.UpdateState(msg)
+
+	// this is similar to m.sidebarModel.UpdateState(msg) but since helpMenu is not a Model
+	// we call .Update() manually here
+	var helpMenuCmd tea.Cmd
+	if m.helpMenu.searchBar.Focused() {
+		m.helpMenu.searchBar, helpMenuCmd = m.helpMenu.searchBar.Update(msg)
+	}
+
+	forcePreviewRender := false
 
 	switch msg := msg.(type) {
-	case channelMessage:
-		m.handleChannelMessage(msg)
 	case tea.WindowSizeMsg:
+		// Must re-render file preview on resize
 		m.handleWindowResize(msg)
+		forcePreviewRender = true
 	case tea.MouseMsg:
-		msgStr := msg.String()
-		if msgStr == "wheel up" || msgStr == "wheel down" {
-			wheelMainAction(msgStr, &m)
-		} else {
-			slog.Debug("Mouse event of type that is not handled", "msg", msgStr)
-		}
+		m.handleMouseMsg(msg)
 	case tea.KeyMsg:
-		cmd = tea.Batch(cmd, m.handleKeyInput(msg))
-	case MetadataMsg:
-		// Update the metadata and return
-		m.handleMetadataMsg(msg)
-		return m, cmd
+		inputCmd = m.handleKeyInput(msg)
+
+	// Has to handle zoxide messages separately as they could be generated via
+	// zoxide update commands, or batched commands from textinput
+	// Cannot do it like processbar messages
+	case zoxideui.UpdateMsg:
+		slog.Debug("Got ModelUpdate message", "id", msg.GetReqID())
+		gotModelUpdateMsg = true
+		updateCmd = msg.Apply(&m.zoxideModal)
+	case ModelUpdateMessage:
+		// TODO: Some of these updates messages should trigger filePanel state update
+		// For example a success message for delete operation
+		// But, we cant do that as of now, because if every opertion including metadata operation
+		// keeps triggering model update below, which will trigger another metadata fetch,
+		// we will be stuck in a loop.
+		slog.Debug("Got ModelUpdate message", "id", msg.GetReqID())
+		gotModelUpdateMsg = true
+		updateCmd = msg.ApplyToModel(m)
+
 	default:
-		slog.Debug("Message of type that is not handled", "type", reflect.TypeOf(msg))
+		slog.Debug("Message of type that is not handled")
 	}
 
-	m.updateFilePanelsState(msg, &cmd)
+	// This is needed for blink, etc to work
+	panelCmd = m.updateFilePanelsState(msg)
+
+	m.updateModelStateAfterMsg()
+
+	// Temp fix till we add metadata cache, to prevent multiple metadata fetch spawns
+	// Ideally we might want to fetch only if the current file selected in filepanel changes
+	if !gotModelUpdateMsg {
+		metadataCmd = m.getMetadataCmd()
+		filePreviewCmd = m.getFilePreviewCmd(forcePreviewRender)
+	}
+
+	return m, tea.Batch(sidebarCmd, helpMenuCmd, inputCmd, updateCmd, panelCmd, metadataCmd, filePreviewCmd)
+}
+
+func (m *model) handleMouseMsg(msg tea.MouseMsg) {
+	msgStr := msg.String()
+	if msgStr == "wheel up" || msgStr == "wheel down" {
+		wheelMainAction(msgStr, m)
+	} else {
+		slog.Debug("Mouse event of type that is not handled", "msg", msgStr)
+	}
+}
+
+func (m *model) updateModelStateAfterMsg() {
 	m.sidebarModel.UpdateDirectories()
-
-	// check if there already have listening message
-	// TODO: Fix this. This is wrong, and it will cause unnecessary goroutines spawned continuously
-	// for every Update() , stuck listening for channel message
-	// We could move to only issuing listen commands on receiving channel messages.
-	// Have the channel as a part of model struct, and remove ListeningMessage variable altogether.
-	// See - Issue #946
-	var listenChannelCommand tea.Cmd
-	if !ListeningMessage {
-		listenChannelCommand = listenForChannelMessage(channel)
-	}
-
 	m.getFilePanelItems()
-
-	metadataCmd := m.getMetadataCmd()
-
 	// TODO: Move to utility
 	if m.focusPanel != metadataFocus {
 		m.fileMetaData.ResetRender()
 	}
-
 	// TODO: Entirely remove the need of this variable, and handle first loading via Init()
 	// Init() should return a basic model object with all IO waiting via a tea.Cmd
 	if !m.firstLoadingComplete {
 		m.firstLoadingComplete = true
 	}
-	return m, tea.Batch(cmd, listenChannelCommand, metadataCmd)
 }
 
-func (m *model) handleMetadataMsg(msg MetadataMsg) {
-	slog.Debug("Got metadata message", "id", msg.reqID)
+func (m *model) getFilePreviewCmd(forcePreviewRender bool) tea.Cmd {
+	if !m.fileModel.filePreview.IsOpen() {
+		return nil
+	}
+	if len(m.getFocusedFilePanel().element) == 0 {
+		// Sync call because this will be fast
+		m.fileModel.filePreview.SetContentWithRenderText("")
+		return nil
+	}
+	selectedItem := m.getFocusedFilePanel().getSelectedItem()
+	if m.fileModel.filePreview.GetLocation() == selectedItem.location && !forcePreviewRender {
+		return nil
+	}
 
-	selectedItem := m.getFocusedFilePanel().getSelectedItemPtr()
-	if selectedItem == nil {
-		slog.Debug("Panel empty or cursor invalid. Ignoring MetadataMsg")
-		return
+	m.fileModel.filePreview.SetLocation(selectedItem.location)
+	m.fileModel.filePreview.SetContentWithRenderText("Loading...")
+	reqCnt := m.ioReqCnt
+	m.ioReqCnt++
+	slog.Debug("Submitting file preview render request", "id", reqCnt, "path", selectedItem.location)
+
+	// Copy to a local variable to be used in below closure.
+	fullModalWidth := m.fullWidth
+
+	return func() tea.Msg {
+		return NewFilePreviewUpdateMsg(selectedItem.location,
+			m.fileModel.filePreview.RenderWithPath(selectedItem.location, fullModalWidth), reqCnt)
 	}
-	if selectedItem.location != msg.metadata.GetPath() {
-		slog.Debug("MetadataMsg for older files. Ignoring")
-		return
-	}
-	m.fileMetaData.SetMetadata(msg.metadata)
-	selectedItem.metaData = msg.metadata.GetData()
 }
 
 // Note : Maybe we should not trigger metadata fetch for updates
@@ -143,6 +180,9 @@ func (m *model) handleMetadataMsg(msg MetadataMsg) {
 // TODO : At least dont trigger metadata fetch when user is scrolling
 // through the metadata panel
 func (m *model) getMetadataCmd() tea.Cmd {
+	if m.disableMetadata {
+		return nil
+	}
 	if len(m.getFocusedFilePanel().element) == 0 {
 		m.fileMetaData.SetBlank()
 		return nil
@@ -164,38 +204,14 @@ func (m *model) getMetadataCmd() tea.Cmd {
 		m.fileMetaData.SetInfoMsg(icon.InOperation + icon.Space + "Loading metadata...")
 	}
 	metadataFocussed := m.focusPanel == metadataFocus
-	reqCnt := m.metadataRequestCnt
-	m.metadataRequestCnt++
+	reqCnt := m.ioReqCnt
+	m.ioReqCnt++
 	// If there are too many metadata fetches, we need to have a cache with path as a key
 	// and timeout based eviction
 	slog.Debug("Submitting metadata fetch request", "id", reqCnt, "path", selectedItem.location)
 	return func() tea.Msg {
-		return MetadataMsg{
-			metadata: metadata.GetMetadata(selectedItem.location, metadataFocussed, et),
-			reqID:    reqCnt,
-		}
-	}
-}
-
-// Handle message exchanging within the application
-func (m *model) handleChannelMessage(msg channelMessage) {
-	switch msg.messageType {
-	case sendWarnModal:
-		m.warnModal = msg.warnModal
-	case sendNotifyModal:
-		m.notifyModal = msg.notifyModal
-	case sendProcess:
-		if !arrayContains(m.processBarModel.processList, msg.messageID) {
-			m.processBarModel.processList = append(m.processBarModel.processList, msg.messageID)
-		}
-		m.processBarModel.process[msg.messageID] = msg.processNewState
-		// Check if the process is cut and if the process is successful or failure, both need to be reset
-		if (msg.processNewState.state == successful || msg.processNewState.state == failure) && m.copyItems.cut {
-			m.copyItems.reset(false)
-		}
-	default:
-		slog.Error("Unhandled channelMessageType in handleChannelMessage()",
-			"messageType", msg.messageType)
+		return NewMetadataMsg(
+			metadata.GetMetadata(selectedItem.location, metadataFocussed, et), reqCnt)
 	}
 }
 
@@ -204,36 +220,45 @@ func (m *model) handleWindowResize(msg tea.WindowSizeMsg) {
 	m.fullHeight = msg.Height
 	m.fullWidth = msg.Width
 
-	if m.fileModel.filePreview.open {
+	m.setHeightValues(msg.Height)
+
+	if m.fileModel.filePreview.IsOpen() {
 		// File preview panel width same as file panel
-		m.setFilePreviewWidth(msg.Width)
+		m.setFilePreviewPanelSize()
 	}
 
 	m.setFilePanelsSize(msg.Width)
-	m.setHeightValues(msg.Height)
 	m.setHelpMenuSize()
 	m.setMetadataModelSize()
+	m.setProcessBarModelSize()
 	m.setPromptModelSize()
+	m.setZoxideModelSize()
 
 	if m.fileModel.maxFilePanel >= 10 {
 		m.fileModel.maxFilePanel = 10
 	}
 }
 
+func (m *model) setFilePreviewPanelSize() {
+	m.fileModel.filePreview.SetWidth(m.getFilePreviewWidth())
+	m.fileModel.filePreview.SetHeight(m.mainPanelHeight + 2)
+}
+
 // Set file preview panel Widht to width. Assure that
-func (m *model) setFilePreviewWidth(width int) {
+func (m *model) getFilePreviewWidth() int {
 	if common.Config.FilePreviewWidth == 0 {
-		m.fileModel.filePreview.width = (width - common.Config.SidebarWidth - (4 + (len(m.fileModel.filePanels))*2)) / (len(m.fileModel.filePanels) + 1)
-	} else {
-		m.fileModel.filePreview.width = (width - common.Config.SidebarWidth) / common.Config.FilePreviewWidth
+		return (m.fullWidth - common.Config.SidebarWidth -
+			(4 + (len(m.fileModel.filePanels))*2)) / (len(m.fileModel.filePanels) + 1)
 	}
+	return (m.fullWidth - common.Config.SidebarWidth) / common.Config.FilePreviewWidth
 }
 
 // Proper set panels size. Assure that panels do not overlap
 func (m *model) setFilePanelsSize(width int) {
 	// set each file panel size and max file panel amount
-	m.fileModel.width = (width - common.Config.SidebarWidth - m.fileModel.filePreview.width - (4 + (len(m.fileModel.filePanels)-1)*2)) / len(m.fileModel.filePanels)
-	m.fileModel.maxFilePanel = (width - common.Config.SidebarWidth - m.fileModel.filePreview.width) / 20
+	m.fileModel.width = (width - common.Config.SidebarWidth - m.fileModel.filePreview.GetWidth() -
+		(4 + (len(m.fileModel.filePanels)-1)*2)) / len(m.fileModel.filePanels)
+	m.fileModel.maxFilePanel = (width - common.Config.SidebarWidth - m.fileModel.filePreview.GetWidth()) / 20
 	for i := range m.fileModel.filePanels {
 		m.fileModel.filePanels[i].searchBar.Width = m.fileModel.width - 4
 	}
@@ -259,6 +284,10 @@ func (m *model) setHeightValues(height int) {
 
 	// Main panel height = Total terminal height- 2(file panel border) - footer height
 	m.mainPanelHeight = height - 2 - utils.FullFooterHeight(m.footerHeight, m.toggleFooter)
+
+	for index := range m.fileModel.filePanels {
+		m.fileModel.filePanels[index].handleResize(m.mainPanelHeight)
+	}
 }
 
 // Set help menu size
@@ -273,6 +302,9 @@ func (m *model) setHelpMenuSize() {
 	if m.fullWidth > 95 {
 		m.helpMenu.width = 90
 	}
+	// 2 for border, 1 for left padding, 2 for placeholder icon of searchbar
+	// 1 for additional character that View() of search bar function mysteriously adds.
+	m.helpMenu.searchBar.Width = m.helpMenu.width - 6
 }
 
 func (m *model) setPromptModelSize() {
@@ -283,10 +315,23 @@ func (m *model) setPromptModelSize() {
 	m.promptModal.SetWidth(m.fullWidth / 2)
 }
 
+func (m *model) setZoxideModelSize() {
+	// Scale zoxide model's maxHeight - 50% of total height to accommodate scroll indicators
+	m.zoxideModal.SetMaxHeight(m.fullHeight / 2)
+
+	// Scale zoxide model's width - 50% of total width
+	m.zoxideModal.SetWidth(m.fullWidth / 2)
+}
+
 func (m *model) setMetadataModelSize() {
 	m.fileMetaData.SetDimensions(utils.FooterWidth(m.fullWidth)+2, m.footerHeight+2)
 }
 
+// TODO: Remove this code duplication with footer models
+func (m *model) setProcessBarModelSize() {
+	m.processBarModel.SetDimensions(utils.FooterWidth(m.fullWidth)+2, m.footerHeight+2)
+}
+
 // Identify the current state of the application m and properly handle the
 // msg keybind pressed
 func (m *model) handleKeyInput(msg tea.KeyMsg) tea.Cmd {
@@ -295,10 +340,10 @@ func (m *model) handleKeyInput(msg tea.KeyMsg) tea.Cmd {
 		"alt", msg.Alt)
 	slog.Debug("model.handleKeyInput. model info. ",
 		"filePanelFocusIndex", m.filePanelFocusIndex,
-		"filePanel.focusType", m.fileModel.filePanels[m.filePanelFocusIndex].focusType,
+		"filePanel.isFocused", m.fileModel.filePanels[m.filePanelFocusIndex].isFocused,
 		"filePanel.panelMode", m.fileModel.filePanels[m.filePanelFocusIndex].panelMode,
 		"typingModal.open", m.typingModal.open,
-		"warnModal.open", m.warnModal.open,
+		"notifyModel.open", m.notifyModel.IsOpen(),
 		"promptModal.open", m.promptModal.IsOpen(),
 		"fileModel.renaming", m.fileModel.renaming,
 		"searchBar.focussed", m.fileModel.filePanels[m.filePanelFocusIndex].searchBar.Focused(),
@@ -311,22 +356,25 @@ func (m *model) handleKeyInput(msg tea.KeyMsg) tea.Cmd {
 		return nil
 	}
 	var cmd tea.Cmd
-	quitSuperfile := false
+	cdOnQuit := common.Config.CdOnQuit
 	switch {
 	case m.typingModal.open:
 		m.typingModalOpenKey(msg.String())
 	case m.promptModal.IsOpen():
 		// Ignore keypress. It will be handled in Update call via
 		// updateFilePanelState
+		// TODO: Convert that to async via tea.Cmd
+	case m.zoxideModal.IsOpen():
+		// Ignore keypress. It will be handled in Update call via
+		// updateFilePanelState
 
 	// Handles all warn models except the warn model for confirming to quit
-	case m.warnModal.open:
-		m.warnModalOpenKey(msg.String())
-	case m.notifyModal.open:
-		m.notifyModalOpenKey(msg.String())
+	case m.notifyModel.IsOpen():
+		cmd = m.notifyModelOpenKey(msg.String())
+
 	// If renaming a object
 	case m.fileModel.renaming:
-		m.renamingKey(msg.String())
+		cmd = m.renamingKey(msg.String())
 	case m.sidebarModel.IsRenaming():
 		m.sidebarRenamingKey(msg.String())
 	// If search bar is open
@@ -340,29 +388,32 @@ func (m *model) handleKeyInput(msg tea.KeyMsg) tea.Cmd {
 	// If help menu is open
 	case m.helpMenu.open:
 		m.helpMenuKey(msg.String())
-	// If asking to confirm quiting
-	case m.modelQuitState == confirmToQuit:
-		quitSuperfile = m.confirmToQuitSuperfile(msg.String())
 
 	case slices.Contains(common.Hotkeys.Quit, msg.String()):
 		m.modelQuitState = quitInitiated
 
+	case slices.Contains(common.Hotkeys.CdQuit, msg.String()):
+		m.modelQuitState = quitInitiated
+		cdOnQuit = true
+
 	default:
 		// Handles general kinds of inputs in the regular state of the application
 		cmd = m.mainKey(msg.String())
 	}
+
 	// If quiting input pressed, check if has any running process and displays a
 	// warn. Otherwise just quits application
 	if m.modelQuitState == quitInitiated {
-		if m.hasRunningProcesses() {
+		if m.processBarModel.HasRunningProcesses() {
 			// Dont quit now, get a confirmation first.
+			m.modelQuitState = quitConfirmationInitiated
 			m.warnModalForQuit()
 			return cmd
 		}
-		quitSuperfile = true
+		m.modelQuitState = quitConfirmationReceived
 	}
-	if quitSuperfile {
-		m.quitSuperfile()
+	if m.modelQuitState == quitConfirmationReceived {
+		m.quitSuperfile(cdOnQuit)
 		return tea.Quit
 	}
 	return cmd
@@ -370,25 +421,27 @@ func (m *model) handleKeyInput(msg tea.KeyMsg) tea.Cmd {
 
 // Update the file panel state. Change name of renamed files, filter out files
 // in search, update typingb bar, etc
-func (m *model) updateFilePanelsState(msg tea.Msg, cmd *tea.Cmd) {
+func (m *model) updateFilePanelsState(msg tea.Msg) tea.Cmd {
 	focusPanel := &m.fileModel.filePanels[m.filePanelFocusIndex]
+	var cmd tea.Cmd
+	var action common.ModelAction
 	switch {
 	case m.firstTextInput:
 		m.firstTextInput = false
 	case m.fileModel.renaming:
-		focusPanel.rename, *cmd = focusPanel.rename.Update(msg)
+		focusPanel.rename, cmd = focusPanel.rename.Update(msg)
 	case focusPanel.searchBar.Focused():
-		focusPanel.searchBar, *cmd = focusPanel.searchBar.Update(msg)
+		focusPanel.searchBar, cmd = focusPanel.searchBar.Update(msg)
 	case m.typingModal.open:
-		m.typingModal.textInput, *cmd = m.typingModal.textInput.Update(msg)
+		m.typingModal.textInput, cmd = m.typingModal.textInput.Update(msg)
 	case m.promptModal.IsOpen():
-		// *cmd is a non-name, and cannot be used on left of :=
-		var action common.ModelAction
-		// Taking returned cmd is necessary for blinking
 		// TODO : Separate this to a utility
 		cwdLocation := m.fileModel.filePanels[m.filePanelFocusIndex].location
-		action, *cmd = m.promptModal.HandleUpdate(msg, cwdLocation)
+		action, cmd = m.promptModal.HandleUpdate(msg, cwdLocation)
 		m.applyPromptModalAction(action)
+	case m.zoxideModal.IsOpen():
+		action, cmd = m.zoxideModal.HandleUpdate(msg)
+		m.applyZoxideModalAction(action)
 	}
 
 	// TODO : This is like duct taping a bigger problem
@@ -396,42 +449,50 @@ func (m *model) updateFilePanelsState(msg tea.Msg, cmd *tea.Cmd) {
 	if focusPanel.cursor < 0 {
 		focusPanel.cursor = 0
 	}
+
+	return cmd
 }
 
 // Apply the Action and notify the promptModal
 func (m *model) applyPromptModalAction(action common.ModelAction) {
-	if _, ok := action.(common.NoAction); !ok {
-		slog.Debug("applyPromptModalAction", "action", action)
-	}
-	var actionErr error
-	var successMsg string
-	switch action := action.(type) {
-	case common.NoAction:
-		return
-	case common.ShellCommandAction:
-		// Update to promptModal is handled here
-		m.applyShellCommandAction(action.Command)
-		return
-	case common.SplitPanelAction:
-		actionErr = m.splitPanel()
-		successMsg = "Panel successfully split"
-	case common.CDCurrentPanelAction:
-		actionErr = m.updateCurrentFilePanelDir(action.Location)
-		successMsg = "Panel directory changed"
-	case common.OpenPanelAction:
-		actionErr = m.createNewFilePanelRelativeToCurrent(action.Location)
-		successMsg = "New panel opened"
-	default:
-		actionErr = errors.New("unhandled action type")
-	}
-
+	successMsg, actionErr := m.logAndExecuteAction(action)
 	if actionErr != nil {
 		m.promptModal.HandleSPFActionResults(false, actionErr.Error())
-	} else {
+	} else if successMsg != "" {
 		m.promptModal.HandleSPFActionResults(true, successMsg)
 	}
 }
 
+// Utility function to log and execute actions, reducing duplication
+func (m *model) logAndExecuteAction(action common.ModelAction) (string, error) {
+	// Only log actions that aren't NoAction to reduce debug noise
+	if _, ok := action.(common.NoAction); !ok {
+		slog.Debug("Applying model action", "action", action)
+	}
+
+	switch action := action.(type) {
+	case common.NoAction:
+		return "", nil
+	case common.ShellCommandAction:
+		// Shell commands are handled separately and don't return here
+		m.applyShellCommandAction(action.Command)
+		return "", nil
+	case common.SplitPanelAction:
+		return "Panel successfully split", m.splitPanel()
+	case common.CDCurrentPanelAction:
+		return "Panel directory changed", m.updateCurrentFilePanelDir(action.Location)
+	case common.OpenPanelAction:
+		return "New panel opened", m.createNewFilePanelRelativeToCurrent(action.Location)
+	default:
+		return "", errors.New("unhandled action type")
+	}
+}
+
+// Apply the Action for zoxide modal (no result notifications needed)
+func (m *model) applyZoxideModalAction(action common.ModelAction) {
+	_, _ = m.logAndExecuteAction(action)
+}
+
 // TODO : Move them around to appropriate places
 func (m *model) applyShellCommandAction(shellCommand string) {
 	focusPanelDir := m.fileModel.filePanels[m.filePanelFocusIndex].location
@@ -458,28 +519,38 @@ func (m *model) createNewFilePanelRelativeToCurrent(path string) error {
 
 // simulates a 'cd' action
 func (m *model) updateCurrentFilePanelDir(path string) error {
-	return m.getFocusedFilePanel().updateCurrentFilePanelDir(path)
+	panel := m.getFocusedFilePanel()
+	err := panel.updateCurrentFilePanelDir(path)
+	if err == nil {
+		// Track the directory change with zoxide
+		m.trackDirectoryWithZoxide(panel.location)
+	}
+	return err
+}
+
+// trackDirectoryWithZoxide adds the directory to zoxide database if zoxide is available and enabled
+func (m *model) trackDirectoryWithZoxide(path string) {
+	if !common.Config.ZoxideSupport || m.zClient == nil {
+		return
+	}
+
+	err := m.zClient.Add(path)
+	if err != nil {
+		slog.Debug("Failed to add directory to zoxide", "path", path, "error", err)
+	}
 }
 
 // Check if there's any processes running in background
-func (m *model) hasRunningProcesses() bool {
-	for _, data := range m.processBarModel.process {
-		if data.state == inOperation && data.done != data.total {
-			return true
-		}
-	}
-	return false
-}
 
 // Triggers a warn for confirm quiting
 func (m *model) warnModalForQuit() {
-	m.modelQuitState = confirmToQuit
-	m.warnModal.title = "Confirm to quit superfile"
-	m.warnModal.content = "You still have files being processed. Are you sure you want to exit?"
+	m.notifyModel = notify.New(true, "Confirm to quit superfile",
+		"You still have files being processed. Are you sure you want to exit?",
+		notify.QuitAction)
 }
 
 // Implement View function for bubble tea model to handle visualization.
-func (m model) View() string {
+func (m *model) View() string {
 	slog.Debug("model.View() called", "mainPanelHeight", m.mainPanelHeight,
 		"footerHeight", m.footerHeight, "fullHeight", m.fullHeight,
 		"fullWidth", m.fullWidth)
@@ -487,7 +558,7 @@ func (m model) View() string {
 	if !m.firstLoadingComplete {
 		return "Loading..."
 	}
-	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
+
 	// check is the terminal size enough
 	if m.fullHeight < common.MinimumHeight || m.fullWidth < common.MinimumWidth {
 		return m.terminalSizeWarnRender()
@@ -508,8 +579,11 @@ func (m model) View() string {
 
 	mainPanel := lipgloss.JoinHorizontal(0, sidebar, filePanel, filePreview)
 
-	var footer string
+	if common.Config.Debug {
+		showRenderDebugStatsMain(sidebar, filePanel, filePreview)
+	}
 
+	var footer string
 	if m.toggleFooter {
 		processBar := m.processBarRender()
 
@@ -518,6 +592,9 @@ func (m model) View() string {
 		clipboardBar := m.clipboardRender()
 
 		footer = lipgloss.JoinHorizontal(0, processBar, metaData, clipboardBar)
+		if common.Config.Debug {
+			showRenderDebugStatsFooter(processBar, metaData, clipboardBar)
+		}
 	}
 
 	var finalRender string
@@ -527,6 +604,13 @@ func (m model) View() string {
 	} else {
 		finalRender = mainPanel
 	}
+
+	finalRender = m.updateRenderForOverlay(finalRender)
+
+	return finalRender
+}
+
+func (m *model) updateRenderForOverlay(finalRender string) string {
 	// check if need pop up modal
 	if m.helpMenu.open {
 		helpMenu := m.helpMenuRender()
@@ -542,6 +626,15 @@ func (m model) View() string {
 		return stringfunction.PlaceOverlay(overlayX, overlayY, promptModal, finalRender)
 	}
 
+	if m.zoxideModal.IsOpen() {
+		zoxideModal := m.zoxideModalRender()
+		overlayX := m.fullWidth/2 - m.zoxideModal.GetWidth()/2
+		overlayY := m.fullHeight/2 - m.zoxideModal.GetMaxHeight()/2
+		return stringfunction.PlaceOverlay(overlayX, overlayY, zoxideModal, finalRender)
+	}
+
+	panel := m.fileModel.filePanels[m.filePanelFocusIndex]
+
 	if panel.sortOptions.open {
 		sortOptions := m.sortOptionsRender()
 		overlayX := m.fullWidth/2 - panel.sortOptions.width/2
@@ -563,48 +656,41 @@ func (m model) View() string {
 		return stringfunction.PlaceOverlay(overlayX, overlayY, typingModal, finalRender)
 	}
 
-	if m.warnModal.open {
-		warnModal := m.warnModalRender()
-		overlayX := m.fullWidth/2 - common.ModalWidth/2
-		overlayY := m.fullHeight/2 - common.ModalHeight/2
-		return stringfunction.PlaceOverlay(overlayX, overlayY, warnModal, finalRender)
-	}
-
-	if m.notifyModal.open {
-		notifyModal := m.notifyModalRender()
+	if m.notifyModel.IsOpen() {
+		notifyModal := m.notifyModel.Render()
 		overlayX := m.fullWidth/2 - common.ModalWidth/2
 		overlayY := m.fullHeight/2 - common.ModalHeight/2
 		return stringfunction.PlaceOverlay(overlayX, overlayY, notifyModal, finalRender)
 	}
-
-	// This is also a render for warnmodal, but its being driven via a different flag
-	// we should also drive it via warnModal.open
-	if m.modelQuitState == confirmToQuit {
-		warnModal := m.warnModalRender()
-		overlayX := m.fullWidth/2 - common.ModalWidth/2
-		overlayY := m.fullHeight/2 - common.ModalHeight/2
-		return stringfunction.PlaceOverlay(overlayX, overlayY, warnModal, finalRender)
-	}
-
 	return finalRender
 }
 
-// Returns a tea.cmd responsible for listening messages from msg channel
-func listenForChannelMessage(msg chan channelMessage) tea.Cmd {
-	return func() tea.Msg {
-		for {
-			m := <-msg
-			if m.messageType != sendProcess {
-				ListeningMessage = false
-				return m
-			}
-			if time.Since(progressBarLastRenderTime).Seconds() > 2 || m.processNewState.state == successful || m.processNewState.done < 2 {
-				ListeningMessage = false
-				progressBarLastRenderTime = time.Now()
-				return m
-			}
-		}
+func showRenderDebugStatsMain(sidebar, filePanel, filePreview string) {
+	slog.Debug("Render stats for main panel",
+		"sidebarLineCnt", getLineCnt(sidebar), "sidebarMaxW", getMaxW(sidebar),
+		"filePanelLineCnt", getLineCnt(filePanel), "filePanelMaxW", getMaxW(filePanel),
+		"filePreviewLineCnt", getLineCnt(filePreview), "filePreviewMaxW", getMaxW(filePreview),
+	)
+}
+
+func showRenderDebugStatsFooter(processBar, metaData, clipboardBar string) {
+	slog.Debug("Render stats for footer",
+		"processBarLineCnt", getLineCnt(processBar), "processBarMaxW", getMaxW(processBar),
+		"metaDataLineCnt", getLineCnt(metaData), "metaDataMaxW", getMaxW(metaData),
+		"clipboardBarLineCnt", getLineCnt(clipboardBar), "clipboardBarMaxW", getMaxW(clipboardBar),
+	)
+}
+
+func getLineCnt(s string) int {
+	return strings.Count(s, "\n") + 1
+}
+
+func getMaxW(s string) int {
+	maxW := 0
+	for line := range strings.Lines(s) {
+		maxW = max(maxW, ansi.StringWidth(line))
 	}
+	return maxW
 }
 
 // Render and update file panel items. Check for changes and updates in files and
@@ -615,7 +701,7 @@ func (m *model) getFilePanelItems() {
 		var fileElement []element
 		nowTime := time.Now()
 		// Check last time each element was updated, if less then 3 seconds ignore
-		if filePanel.focusType == noneFocus && nowTime.Sub(filePanel.lastTimeGetElement) < 3*time.Second {
+		if !filePanel.isFocused && nowTime.Sub(filePanel.lastTimeGetElement) < 3*time.Second {
 			// TODO : revisit this. This feels like a duct tape solution of an actual
 			// deep rooted problem. This feels very hacky.
 			if !m.updatedToggleDotFile {
@@ -635,13 +721,15 @@ func (m *model) getFilePanelItems() {
 
 		reRenderTime := int(float64(len(filePanel.element)) / 100)
 
-		if filePanel.focusType != noneFocus && nowTime.Sub(filePanel.lastTimeGetElement) < time.Duration(reRenderTime)*time.Second && !focusPanelReRender {
+		if filePanel.isFocused && !focusPanelReRender &&
+			nowTime.Sub(filePanel.lastTimeGetElement) < time.Duration(reRenderTime)*time.Second {
 			continue
 		}
 
 		// Get file names based on search bar filter
 		if filePanel.searchBar.Value() != "" {
-			fileElement = returnDirElementBySearchString(filePanel.location, m.toggleDotFile, filePanel.searchBar.Value())
+			fileElement = returnDirElementBySearchString(filePanel.location, m.toggleDotFile,
+				filePanel.searchBar.Value(), filePanel.sortOptions.data)
 		} else {
 			fileElement = returnDirElement(filePanel.location, m.toggleDotFile, filePanel.sortOptions.data)
 		}
@@ -656,7 +744,7 @@ func (m *model) getFilePanelItems() {
 
 // Close superfile application. Cd into the current dir if CdOnQuit on and save
 // the path in state direcotory
-func (m *model) quitSuperfile() {
+func (m *model) quitSuperfile(cdOnQuit bool) {
 	// close exiftool session
 	if common.Config.Metadata && et != nil {
 		et.Close()
@@ -665,10 +753,10 @@ func (m *model) quitSuperfile() {
 	currentDir := m.fileModel.filePanels[m.filePanelFocusIndex].location
 	variable.SetLastDir(currentDir)
 
-	if common.Config.CdOnQuit {
+	if cdOnQuit {
 		// escape single quote
 		currentDir = strings.ReplaceAll(currentDir, "'", "'\\''")
-		err := os.WriteFile(variable.LastDirFile, []byte("cd '"+currentDir+"'"), 0755)
+		err := os.WriteFile(variable.LastDirFile, []byte("cd '"+currentDir+"'"), 0o755)
 		if err != nil {
 			slog.Error("Error during writing lastdir file", "error", err)
 		}
@@ -676,15 +764,3 @@ func (m *model) quitSuperfile() {
 	m.modelQuitState = quitDone
 	slog.Debug("Quitting superfile", "current dir", currentDir)
 }
-
-// Check if bat is an executable in PATH and whether to use bat or batcat as command
-func checkBatCmd() string {
-	if _, err := exec.LookPath("bat"); err == nil {
-		return "bat"
-	}
-	// on ubuntu bat executable is called batcat
-	if _, err := exec.LookPath("batcat"); err == nil {
-		return "batcat"
-	}
-	return ""
-}
