@@ -3,7 +3,7 @@ package rendering
 import (
 	"strings"
 
-	"github.com/charmbracelet/x/exp/term/ansi"
+	"github.com/charmbracelet/x/ansi"
 
 	"github.com/charmbracelet/lipgloss"
 )
@@ -28,6 +28,14 @@ type BorderConfig struct {
 	titleLeftMargin int
 }
 
+func NewBorderConfig(height int, width int) BorderConfig {
+	return BorderConfig{
+		height:          height,
+		width:           width,
+		titleLeftMargin: 1,
+	}
+}
+
 func (b *BorderConfig) SetTitle(title string) {
 	b.title = ansi.Strip(title)
 }
@@ -134,11 +142,3 @@ func (b *BorderConfig) GetBorder(borderStrings lipgloss.Border) lipgloss.Border
 
 	return res
 }
-
-func NewBorderConfig(height int, width int) BorderConfig {
-	return BorderConfig{
-		height:          height,
-		width:           width,
-		titleLeftMargin: 1,
-	}
-}
